Learn R Programming

globalKinhom (version 0.1.7)

globalKinhom-package: tools:::Rd_package_title("globalKinhom")

Description

tools:::Rd_package_description("globalKinhom")

Arguments

Author

tools:::Rd_package_author("globalKinhom")

Maintainer: tools:::Rd_package_maintainer("globalKinhom")

Details

The DESCRIPTION file: tools:::Rd_package_DESCRIPTION("globalKinhom") tools:::Rd_package_indices("globalKinhom")

This package accompanies Shaw et al (2020). It provides “global” estimators for the non-parametric \(K\)- and pair correlation functions, which summarize the second order interactions of second-order intensity-reweighted stationary (SOIRS) point processes. These estimators provide an alternative to those proposed by Baddeley et al (2000) for SOIRS point processes, which we refer to as “local” estimators. The local estimators are implemented in the spatstat.explore package as pcfinhom and Kinhom, with pcfcross.inhom and Kcross.inhom for the corresponding cross-pcf and cross-\(K\)-function.

Where possible, the interfaces are made to match those used by the spatstat.explore package.

References

T Shaw, J Møller, R Waagepetersen. 2020. “Globally Intensity-Reweighted Estimators for \(K\)- and pair correlation functions”. arXiv:2004.00527 [stat.ME].

A Baddeley, J Møller, R Waagepetersen. 2000. “Non- and Semi-Parametric Estimation of Interaction in Inhomogeneous Point Patterns”. Statistica Neerlandica 54, 329-350.

See Also

spatstat.explore, Kglobal, link{pcfglobal}